/*
    CFS0.11 filesystem implementation for FUSE
    Copyright (C) 2005-2020 Kajtar Zsolt (Soci/Singular) <soci@c64.rulez.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
#ifndef FILE_H
#define FILE_H
#include <stdlib.h>
#include <sys/stat.h>

typedef unsigned int Offset;
typedef unsigned char Petscii;
struct Partition;

typedef struct {
    mode_t attr;
//    int attr;
    off_t size;
//    int size;
    struct Partition *partition;
    int file_offset;
    Offset dir_sector;
    int empty_offset;
    Offset empty_sector;
    Offset this_dir;
    Offset end_of_this_dir;
    Offset root;
    size_t sectors;
    Petscii name[16 + 1];
    Petscii type[3 + 1];
    unsigned char date[4];
} resolv_t;

typedef struct File {
    size_t refcount;
    Offset treeroot;
    Offset lastblock, lasttree;
    struct Partition *partition;
    Offset dir_sector;
    int dir_offset;
    struct File *next;
} File;

extern File *file_lookup(const resolv_t *at);
extern File *file_open(const resolv_t *at);
extern void file_close(File *file);
#endif
